# Python WeatherKit Client

This is a Python client for Apple's WeatherKit API. It is primarily written for use with the [Home Assistant](https://www.home-assistant.io/) integration, but can be used for other purposes as well.